@@ -22,8 +22,4 @@ sub  prepare {
 
 }
 
-sub end : Private {
-    my ($self,$c) = @_;
-}
-
 1;
